@@ -62,7 +62,8 @@ class BytestreamDataSource(DataSource):
                         message_buffer)
                 if message is None:
                     break
-                if not (('name' in message and 'value' in message) or (
+                if not hasattr(message, '__iter__') or not (
+                        ('name' in message and 'value' in message) or (
                         'id' in message and 'data' in message)):
                     self.corrupted_messages += 1
                     break
@@ -79,6 +80,8 @@ class BytestreamDataSource(DataSource):
         Returns the message if one could be parsed, otherwise None, and the
         remainder of the buffer.
         """
+        if not isinstance(message_buffer, bytes):
+            message_buffer = message_buffer.encode("utf-8")
         parsed_message = None
         remainder = message_buffer
         message = ""
