@@ -2,12 +2,16 @@
 from __future__ import absolute_import
 
 import logging
-import serial
 
 from .base import BytestreamDataSource, DataSourceError
 
 LOG = logging.getLogger(__name__)
 
+try:
+    import serial
+except ImportError:
+    LOG.debug("serial library not installed, can't use serial interface")
+
 
 class SerialDataSource(BytestreamDataSource):
     """A data source reading from a serial port, which could be implemented
